use `ombutel`;

create table `ombu_sip_trunks` (
	`trunk_id` int unsigned not null primary key,
	`register` varchar(255) default null,
	`codecs` varchar(255) default null,
	`register_flag` enum('no','yes') not null default 'yes',
	`outgoing_username` varchar(255) not null,
	`outgoing_host` varchar(255) not null,
	`outgoing_port` int unsigned not null default 5060,
	`outgoing_defaultuser` varchar(255) default null,
	`outgoing_remotesecret` varchar(255) default null,
	`outgoing_secret` varchar(255) default null,
	`outgoing_fromuser` varchar(255) default null,
	`outgoing_fromdomain` varchar(255) default null,
	`outgoing_insecure` varchar(255) default null,
	`outgoing_type` enum('no','yes') not null default 'no',
	`outgoing_qualify` enum('no','yes') not null default 'yes',
	`incoming_username` varchar(255) default null,
	`incoming_host` varchar(255) default null,
	`incoming_secret` varchar(255) default null,
	`incoming_insecure` varchar(255) default null,
	`incoming_type` enum('no','yes') not null default 'no',
	`incoming_qualify` enum('no','yes') not null default 'yes',
	`diversion_sipheader` enum('no','yes') not null default 'no',
	`did_header` enum('default','to') not null default 'default',
	`mt_outbound_proxy` varchar(255) default null,
	`mt_external_ip` varchar(255) default null,
	foreign key (`trunk_id`) references `ombu_trunks`(`trunk_id`) on delete cascade
);

create table `ombu_sip_trunk_parameters` (
	`trunk_id` int unsigned not null,
	`type` enum('peer','user','friend') not null default 'friend',
	`param` varchar(255) not null,
	`value` varchar(255) not null,
	`enabled` enum('no','yes') not null default 'yes',
	`sort` int unsigned not null default 0,
	foreign key (`trunk_id`) references `ombu_sip_trunks`(`trunk_id`) on delete cascade
);

create table `ombu_sip_trunk_sources` (
	`trunk_id` int unsigned not null,
	`source` varchar(255) not null,
	foreign key (`trunk_id`) references `ombu_sip_trunks`(`trunk_id`) on delete cascade
);

create table `ombu_iax_trunks` (
	`trunk_id` int unsigned not null primary key,
	`register` varchar(255) default null,
	`codecs` varchar(255) default null,
	`register_flag` enum('no','yes') not null default 'yes',
	`outgoing_username` varchar(255) not null,
	`outgoing_host` varchar(255) not null,
	`outgoing_port` int unsigned not null default 4569,
	`outgoing_defaultuser` varchar(255) default null,
	`outgoing_remotesecret` varchar(255) default null,
	`outgoing_secret` varchar(255) default null,
	`outgoing_type` enum('no','yes') not null default 'no',
	`outgoing_trunk` enum('no','yes') not null default 'yes',
	`outgoing_qualify` enum('no','yes') not null default 'yes',
	`incoming_username` varchar(255) default null,
	`incoming_host` varchar(255) default null,
	`incoming_defaultuser` varchar(255) default null,
	`incoming_secret` varchar(255) default null,
	`incoming_remotesecret` varchar(255) default null,
	`incoming_trunk` enum('no','yes') not null default 'yes',
	`incoming_qualify` enum('no','yes') not null default 'yes',
	foreign key (`trunk_id`) references `ombu_trunks`(`trunk_id`) on delete cascade
);

create table `ombu_iax_trunk_parameters` (
	`trunk_id` int unsigned not null,
	`type` enum('peer','user','friend') not null default 'friend',
	`param` varchar(255) not null,
	`value` varchar(255) not null,
	`enabled` enum('no','yes') not null default 'yes',
	`sort` int unsigned not null default 0,
	foreign key (`trunk_id`) references `ombu_iax_trunks`(`trunk_id`) on delete cascade
);

create table `ombu_telephony_trunks` (
	`trunk_id` int unsigned not null primary key,
	`group_id` int unsigned default null,
	`channel_id` int unsigned default null,
	`group_mode` enum('g','G','r','R') character set binary not null default 'g',
	`dst_type` enum('groups','channels') not null default 'groups',
	foreign key (`trunk_id`) references `ombu_trunks`(`trunk_id`) on delete cascade,
	foreign key (`group_id`) references `ombu_dahdi_groups`(`group_id`) on delete set null,
	foreign key (`channel_id`) references `ombu_dahdi_channels`(`channel_id`) on delete set null
);

create table `ombu_telephony_trunk_parameters` (
	`trunk_id` int unsigned not null,
	`param` varchar(255) not null,
	`value` varchar(255) not null,
	`enabled` enum('no','yes') not null default 'yes',
	`sort` int unsigned not null default 0,
	foreign key (`trunk_id`) references `ombu_telephony_trunks`(`trunk_id`) on delete cascade
);

create table `ombu_h323_trunks` (
	`trunk_id` int unsigned not null primary key,
	`username` varchar(255) not null,
	`hostname` varchar(255) not null,
	`port` int unsigned not null default 1720,
	foreign key (`trunk_id`) references `ombu_trunks`(`trunk_id`) on delete cascade
);

create table `ombu_h323_trunk_parameters` (
	`trunk_id` int unsigned not null,
	`type` enum('peer','user','friend') not null,
	`param` varchar(255) not null,
	`value` varchar(255) not null,
	`enabled` enum('no','yes') not null default 'yes',
	`sort` int unsigned not null default 0,
	foreign key (`trunk_id`) references `ombu_h323_trunks`(`trunk_id`) on delete cascade
);

insert into `ombu_sip_trunks` (
	`trunk_id`, `register`, `codecs`, `register_flag`, `outgoing_username`, `outgoing_host`, `outgoing_port`,
	`outgoing_defaultuser`, `outgoing_remotesecret`, `outgoing_secret`, `outgoing_fromuser`,
	`outgoing_fromdomain`, `outgoing_insecure`, `outgoing_type`, `outgoing_qualify`, `incoming_username`,
	`incoming_host`, `incoming_secret`, `incoming_insecure`, `incoming_type`, `incoming_qualify`,
	`diversion_sipheader`, `did_header`, `mt_outbound_proxy`, `mt_external_ip`
) select
	t.`trunk_id`, t.`register`, t.`codecs`, t.`register_flag`, t.`outgoing_username`, tp1.`value`,
	if(tp2.`value` = '', 5060, tp2.`value`), tp3.`value`, tp4.`value`, tp5.`value`, tp6.`value`,
	tp7.`value`, tp8.`value`, tp9.`value`, tp10.`value`, t.`incoming_username`, tp11.`value`, tp12.`value`,
	tp13.`value`, tp14.`value`, tp15.`value`, t.`diversion_sipheader`, t.`did_header`, mt1.`value`, mt2.`value`
from `ombu_trunks` t
left join `ombu_trunk_parameters` tp1 on (
	tp1.`trunk_id` = t.`trunk_id` and tp1.`advanced_param` = 'no' and tp1.`param` = 'outgoing_host'
) left join `ombu_trunk_parameters` tp2 on (
	tp2.`trunk_id` = t.`trunk_id` and tp2.`advanced_param` = 'no' and tp2.`param` = 'outgoing_port'
) left join `ombu_trunk_parameters` tp3 on (
	tp3.`trunk_id` = t.`trunk_id` and tp3.`advanced_param` = 'no' and tp3.`param` = 'outgoing_defaultuser'
) left join `ombu_trunk_parameters` tp4 on (
	tp4.`trunk_id` = t.`trunk_id` and tp4.`advanced_param` = 'no' and tp4.`param` = 'outgoing_remotesecret'
) left join `ombu_trunk_parameters` tp5 on (
	tp5.`trunk_id` = t.`trunk_id` and tp5.`advanced_param` = 'no' and tp5.`param` = 'outgoing_secret'
) left join `ombu_trunk_parameters` tp6 on (
	tp6.`trunk_id` = t.`trunk_id` and tp6.`advanced_param` = 'no' and tp6.`param` = 'outgoing_fromuser'
) left join `ombu_trunk_parameters` tp7 on (
	tp7.`trunk_id` = t.`trunk_id` and tp7.`advanced_param` = 'no' and tp7.`param` = 'outgoing_fromdomain'
) left join `ombu_trunk_parameters` tp8 on (
	tp8.`trunk_id` = t.`trunk_id` and tp8.`advanced_param` = 'no' and tp8.`param` = 'outgoing_insecure'
) left join `ombu_trunk_parameters` tp9 on (
	tp9.`trunk_id` = t.`trunk_id` and tp9.`advanced_param` = 'no' and tp9.`param` = 'outgoing_type'
) left join `ombu_trunk_parameters` tp10 on (
	tp10.`trunk_id` = t.`trunk_id` and tp10.`advanced_param` = 'no' and tp10.`param` = 'outgoing_type'
) left join `ombu_trunk_parameters` tp11 on (
	tp11.`trunk_id` = t.`trunk_id` and tp11.`advanced_param` = 'no' and tp11.`param` = 'incoming_host'
) left join `ombu_trunk_parameters` tp12 on (
	tp12.`trunk_id` = t.`trunk_id` and tp12.`advanced_param` = 'no' and tp12.`param` = 'incoming_secret'
) left join `ombu_trunk_parameters` tp13 on (
	tp13.`trunk_id` = t.`trunk_id` and tp13.`advanced_param` = 'no' and tp13.`param` = 'incoming_insecure'
) left join `ombu_trunk_parameters` tp14 on (
	tp14.`trunk_id` = t.`trunk_id` and tp14.`advanced_param` = 'no' and tp14.`param` = 'incoming_type'
) left join `ombu_trunk_parameters` tp15 on (
	tp15.`trunk_id` = t.`trunk_id` and tp15.`advanced_param` = 'no' and tp15.`param` = 'incoming_qualify'
) left join `ombu_trunk_mt_parameters` mt1 on (
	mt1.`trunk_id` = t.`trunk_id` and mt1.`name` = 'mtob'
) left join `ombu_trunk_mt_parameters` mt2 on (
	mt2.`trunk_id` = t.`trunk_id` and mt2.`name` = 'mtsrc'
) where t.`technology` = 'sip';

insert into `ombu_sip_trunk_parameters` (`trunk_id`, `type`, `param`, `value`, `enabled`, `sort`)
select t.`trunk_id`, tp.`type`, tp.`param`, tp.`value`, tp.`enabled`, tp.`sort`
from `ombu_trunk_parameters` tp
left join `ombu_trunks` t using (`trunk_id`)
where t.`technology` = 'sip' and tp.`advanced_param` = 'yes';

insert into `ombu_sip_trunk_sources` (`trunk_id`, `source`)
select t.`trunk_id`, ts.`value`
from `ombu_trunk_settings` ts
left join `ombu_trunks` t using (`trunk_id`)
where t.`technology` = 'sip' and ts.`name` like 'source_ip_%';

insert into `ombu_iax_trunks` (
	`trunk_id`, `register`, `codecs`, `register_flag`, `outgoing_username`, `outgoing_host`, `outgoing_port`,
	`outgoing_defaultuser`, `outgoing_remotesecret`, `outgoing_secret`, `outgoing_type`, `outgoing_trunk`,
	`outgoing_qualify`, `incoming_username`, `incoming_host`, `incoming_defaultuser`, `incoming_secret`,
	`incoming_remotesecret`, `incoming_trunk`, `incoming_qualify`
) select
	t.`trunk_id`, t.`register`, t.`codecs`, t.`register_flag`, t.`outgoing_username`, tp1.`value`,
	if(tp2.`value` = '', 4569, tp2.`value`), tp3.`value`, tp4.`value`, tp5.`value`, tp6.`value`,
	tp7.`value`, tp8.`value`, t.`incoming_username`, tp9.`value`, tp10.`value`, tp11.`value`, tp12.`value`,
	tp13.`value`, tp14.`value`
from `ombu_trunks` t
left join `ombu_trunk_parameters` tp1 on (
	tp1.`trunk_id` = t.`trunk_id` and tp1.`advanced_param` = 'no' and tp1.`param` = 'outgoing_host'
) left join `ombu_trunk_parameters` tp2 on (
	tp2.`trunk_id` = t.`trunk_id` and tp2.`advanced_param` = 'no' and tp2.`param` = 'outgoing_port'
) left join `ombu_trunk_parameters` tp3 on (
	tp3.`trunk_id` = t.`trunk_id` and tp3.`advanced_param` = 'no' and tp3.`param` = 'outgoing_defaultuser'
) left join `ombu_trunk_parameters` tp4 on (
	tp4.`trunk_id` = t.`trunk_id` and tp4.`advanced_param` = 'no' and tp4.`param` = 'outgoing_remotesecret'
) left join `ombu_trunk_parameters` tp5 on (
	tp5.`trunk_id` = t.`trunk_id` and tp5.`advanced_param` = 'no' and tp5.`param` = 'outgoing_secret'
) left join `ombu_trunk_parameters` tp6 on (
	tp6.`trunk_id` = t.`trunk_id` and tp6.`advanced_param` = 'no' and tp6.`param` = 'outgoing_type'
) left join `ombu_trunk_parameters` tp7 on (
	tp7.`trunk_id` = t.`trunk_id` and tp7.`advanced_param` = 'no' and tp7.`param` = 'outgoing_trunk'
) left join `ombu_trunk_parameters` tp8 on (
	tp8.`trunk_id` = t.`trunk_id` and tp8.`advanced_param` = 'no' and tp8.`param` = 'outgoing_qualify'
) left join `ombu_trunk_parameters` tp9 on (
	tp9.`trunk_id` = t.`trunk_id` and tp9.`advanced_param` = 'no' and tp9.`param` = 'incoming_host'
) left join `ombu_trunk_parameters` tp10 on (
	tp10.`trunk_id` = t.`trunk_id` and tp10.`advanced_param` = 'no' and tp10.`param` = 'incoming_defaultuser'
) left join `ombu_trunk_parameters` tp11 on (
	tp11.`trunk_id` = t.`trunk_id` and tp11.`advanced_param` = 'no' and tp11.`param` = 'incoming_secret'
) left join `ombu_trunk_parameters` tp12 on (
	tp12.`trunk_id` = t.`trunk_id` and tp12.`advanced_param` = 'no' and tp12.`param` = 'incoming_remotesecret'
) left join `ombu_trunk_parameters` tp13 on (
	tp13.`trunk_id` = t.`trunk_id` and tp13.`advanced_param` = 'no' and tp13.`param` = 'incoming_trunk'
) left join `ombu_trunk_parameters` tp14 on (
	tp14.`trunk_id` = t.`trunk_id` and tp14.`advanced_param` = 'no' and tp14.`param` = 'incoming_qualify'
) where t.`technology` = 'iax';

insert into `ombu_iax_trunk_parameters` (`trunk_id`, `type`, `param`, `value`, `enabled`, `sort`)
select t.`trunk_id`, tp.`type`, tp.`param`, tp.`value`, tp.`enabled`, tp.`sort`
from `ombu_trunk_parameters` tp
left join `ombu_trunks` t using (`trunk_id`)
where t.`technology` = 'iax' and tp.`advanced_param` = 'yes';

insert into `ombu_telephony_trunks` (`trunk_id`, `group_id`, `channel_id`, `group_mode`, `dst_type`)
select `trunk_id`, `group_id`, `channel_id`, `group_mode`, `dst_type`
from `ombu_trunks`
where `technology` = 'telephony';

insert into `ombu_telephony_trunk_parameters` (`trunk_id`, `param`, `value`, `enabled`, `sort`)
select t.`trunk_id`, tp.`param`, tp.`value`, tp.`enabled`, tp.`sort`
from `ombu_trunk_parameters` tp
left join `ombu_trunks` t using (`trunk_id`)
where t.`technology` = 'telephony' and tp.`advanced_param` = 'yes';

insert into `ombu_h323_trunks` (`trunk_id`, `username`, `hostname`, `port`)
select t.`trunk_id`, t.`outgoing_username`, tp1.`value`, if (tp2.`value` = '', 1720, tp2.`value`)
from `ombu_trunks` t
left join `ombu_trunk_parameters` tp1 on (
	tp1.`trunk_id` = t.`trunk_id` and tp1.`advanced_param` = 'no' and tp1.`param` = 'outgoing_host'
) left join `ombu_trunk_parameters` tp2 on (
	tp2.`trunk_id` = t.`trunk_id` and tp2.`advanced_param` = 'no' and tp2.`param` = 'outgoing_port'
) where t.`technology` = 'h323';

insert into `ombu_h323_trunk_parameters` (`trunk_id`, `type`, `param`, `value`, `enabled`, `sort`)
select t.`trunk_id`, tp.`type`, tp.`param`, tp.`value`, tp.`enabled`, tp.`sort`
from `ombu_trunk_parameters` tp
left join `ombu_trunks` t using (`trunk_id`)
where t.`technology` = 'h323' and tp.`advanced_param` = 'yes';

update `ombu_trunks` set `technology` = 'iax' where `technology` = 'iax2';
update `ombu_trunks` set `trunk_cid` = '"" <>' where `trunk_cid` = '';
update `ombu_trunks` set `ringtimer` = 120 where `ringtimer` = 0;

alter table `ombu_trunks`
	change column `description` `description` varchar(255) not null,
	change column `ringtimer` `ringtimer` int unsigned not null default 120,
	change column `overwrite_cid` `overwrite_cid` enum('no','yes','empty') not null default 'no',
	change column `trunk_cid` `trunk_cid` varchar(255) not null default '"" <>',
	change column `use_incoming_cid` `use_incoming_cid` enum('no','yes') not null default 'no',
	drop foreign key `ombu_trunks_ibfk_3`,
	drop foreign key `ombu_trunks_ibfk_8`,
	drop column `dialstring`,
	drop column `register`,
	drop column `codecs`,
	drop column `register_flag`,
	drop column `outgoing_username`,
	drop column `incoming_username`,
	drop column `diversion_sipheader`,
	drop column `did_header`,
	drop column `group_id`,
	drop column `channel_id`,
	drop column `group_mode`,
	drop column `dst_type`;

drop table `ombu_trunk_parameters`;
drop table `ombu_trunk_settings`;
drop table `ombu_trunk_mt_parameters`;
